@@ -1,5 +1,6 @@
 import calendar
 import json
+import logging
 import os
 import re
 import shutil
@@ -17,6 +18,8 @@ from .constant import DirSaveFile, FieldConstantResponse, CONSTANT_MAP_FORMAT_FI
 from .custom_mimetypes import CustomMimetypes
 from .dir import APP_TMP_DATA_DIR, STATIC_DATA_DIR
 
+logger = logging.getLogger()
+
 
 @Singleton
 class MobioMediaSDK(object):
@@ -61,13 +64,11 @@ class MobioMediaSDK(object):
                 cache_prefix=cache_prefix,
                 redis_uri=redis_uri,
             )
-
-        self.instance = Producer(
-            {
-                "request.timeout.ms": 20000,
-                "bootstrap.servers": MobioEnvironment.KAFKA_BROKER,
-            }
-        )
+        conf = {
+            "request.timeout.ms": 20000,
+            "bootstrap.servers": MobioEnvironment.KAFKA_BROKER,
+        }
+        self.instance = Producer(conf)
 
     @staticmethod
     def valid_input_upload(file_path, file_data, merchant_id, expire=None):
@@ -92,7 +93,7 @@ class MobioMediaSDK(object):
             try:
                 filename = file_data.filename
             except Exception as ex:
-                print("[ERROR] file_data: {}".format(ex))
+                logger.error("[ERROR] file_data: {}".format(ex))
         if not filename:
             filename = str(uuid.uuid4())
         return filename
@@ -141,7 +142,7 @@ class MobioMediaSDK(object):
         if not filename:
             filename = MobioMediaSDK.get_file_name(file_path=file_path, file_data=file_data)
         host_by_merchant_id = self._get_host_by_merchant_id(merchant_id=merchant_id)
-        print("upload_without_kafka()::get_host_by_merchant_id:: %s" % (time.time() - time_start))
+        logger.debug("upload_without_kafka()::get_host_by_merchant_id:: %s" % (time.time() - time_start))
         dist_file, filename = self.create_dir_save_file(
             folder=STATIC_DATA_DIR,
             merchant_id=merchant_id,
@@ -157,7 +158,7 @@ class MobioMediaSDK(object):
         url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
         if short_link:
             url = os.path.join(host_by_merchant_id, self.folder_static, filename)
-        print("upload_without_kafka()::url:: %s" % (time.time() - time_start))
+        logger.debug("upload_without_kafka()::url:: %s" % (time.time() - time_start))
         data_send_producer = {
             "filename": filename,
             "merchant_id": merchant_id,
@@ -171,7 +172,7 @@ class MobioMediaSDK(object):
         }
 
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_SAVE_INFO_MEDIA_SDK, data=json.dumps(data_send_producer))
-        print("upload_without_kafka()::send message to topic:: %s" % (time.time() - time_start))
+        logger.debug("upload_without_kafka()::send message to topic:: %s" % (time.time() - time_start))
         return {
             FieldConstantResponse.URL: url,
             FieldConstantResponse.LOCAL_PATH: dist_file,
@@ -234,7 +235,7 @@ class MobioMediaSDK(object):
             shutil.move(file_path, tmp_file)
         else:
             file_data.save(tmp_file)
-        print("upload_with_kafka()::move file:: %s" % (time.time() - time_start))
+        logger.debug("upload_with_kafka()::move file:: %s" % (time.time() - time_start))
         dist_file, filename = self.create_dir_save_file(
             folder=STATIC_DATA_DIR,
             merchant_id=merchant_id,
@@ -243,7 +244,7 @@ class MobioMediaSDK(object):
             short_link=short_link
         )
         host_by_merchant_id = self._get_host_by_merchant_id(merchant_id=merchant_id)
-        print("upload_with_kafka()::get_host_by_merchant_id:: %s" % (time.time() - time_start))
+        logger.debug("upload_with_kafka()::get_host_by_merchant_id:: %s" % (time.time() - time_start))
         url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
         if short_link:
             url = os.path.join(host_by_merchant_id, self.folder_static, filename)
@@ -260,7 +261,7 @@ class MobioMediaSDK(object):
             "url": url
         }
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_UPLOAD_MEDIA_SDK, data=json.dumps(data_send_producer))
-        print("upload_with_kafka()::send message to topic:: %s" % (time.time() - time_start))
+        logger.debug("upload_with_kafka()::send message to topic:: %s" % (time.time() - time_start))
         return {
             FieldConstantResponse.URL: url,
             FieldConstantResponse.LOCAL_PATH: dist_file,
@@ -301,14 +302,14 @@ class MobioMediaSDK(object):
         try:
             local_path = re.sub(self.pattern_domain, STATIC_DATA_DIR + "/", url)
         except Exception as ex:
-            print("[ERROR] get local_path_file error %s " % ex)
+            logger.error("[ERROR] get local_path_file error %s " % ex)
             raise Exception("url %s not found" % url)
         if not os.path.isfile(local_path):
             raise Exception("[ERROR] local_path :: %s not exists" % local_path)
         return local_path
 
     def get_binary_by_url(self, url):
-        local_path = self.get_local_path_by_url(url)
+        local_path = self.get_path_by_url(url)
         with open(local_path, "r") as f:
             return f.read()
 
@@ -390,7 +391,7 @@ class MobioMediaSDK(object):
             mimetype_str = magic_init.from_file(file_path)
         else:
             mimetype_str = file_data.mimetype if file_data.mimetype else file_data.content_type
-        print("mimetype_str:: %s" % mimetype_str)
+        logger.info("mimetype_str:: %s" % mimetype_str)
         return mimetype_str
 
     def override_file(
@@ -421,7 +422,7 @@ class MobioMediaSDK(object):
             shutil.move(file_path, tmp_file)
         else:
             file_data.save(tmp_file)
-        print("override_file()::move file:: %s" % (time.time() - time_start))
+        logger.debug("override_file()::move file:: %s" % (time.time() - time_start))
         data_send_producer = {
             "merchant_id": merchant_id,
             "url_override": url,
@@ -432,7 +433,7 @@ class MobioMediaSDK(object):
             topic=ConsumerTopic.TOPIC_OVERRIDE_MEDIA_SDK,
             data=json.dumps(data_send_producer)
         )
-        print("override_file()::send message to topic:: %s" % (time.time() - time_start))
+        logger.debug("override_file()::send message to topic:: %s" % (time.time() - time_start))
 
     def delete_file(
             self,
@@ -441,7 +442,7 @@ class MobioMediaSDK(object):
             type_delete=None
     ):
         if not urls:
-            print("[ERROR] urls empty")
+            logger.error("[ERROR] urls empty")
             return None
 
         data_send_producer = {
@@ -461,5 +462,5 @@ class MobioMediaSDK(object):
     def send_message_to_topic(self, topic: str, data):
         self.instance.produce(topic, data)
         self.instance.poll(0)
-        print("topic: {}, message: {}".format(topic, data))
+        logger.info("topic: {}, message: {}".format(topic, data))
         self.instance.flush()
